@@ -48,26 +48,41 @@ class TemplateVolumeConfig(PluginTemplateExtension):
 
         drives = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
         drives_id = []
-        lonely_drive = []
-        linux_devices = []
+        lonely_drives = []
+        drives_with_partition = []
+        partitions = []
         for drive_id in drives:
             print(f"Right Page: {drive_id['drive']}")
             drives_id.append(drive_id['drive'])
-            drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
-            if LinuxDevice.objects.filter(content_type_id=drive_type_id).count() > 0:
-                drive = Drive.objects.get(pk=drive_id['drive'])
-                print(f"Right Page Lonely Drive: {drive}")
-                lonely_drive.append(drive)
+            drive = Drive.objects.get(pk=drive_id['drive'])
 
-            print(f"R Lonely Drives: {lonely_drive}")
-            print(f"R drives: {drives_id}")
-            print(linux_devices)
+            drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
+            linux_device_type_id = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
+            print(f"{drive_type_id}, {drive_id['drive']}")
+            # Get Linux Device of Drive e.g. /dev/sda
+            linux_device_drive = LinuxDevice.objects.get(content_type_id=drive_type_id, object_id=drive_id['drive'], type='disk')
+            print(f"Count: {linux_device_drive}")
+            # Wenn es keine Partition hat zu lonely_drives hinzufügen
+            if LinuxDevice.objects.filter(content_type_id=linux_device_type_id, object_id=linux_device_drive.pk,
+                                          type='Partition').count() == 0:
+                print(f"Right Page Lonely Drive: {drive}")
+                lonely_drives.append(drive)
+            else:
+                drives_with_partition.append(drive)
+                partitions.append(list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
+                                                                  object_id=linux_device_drive.pk, type='Partition')))
+
+        amount_partitions = len(partitions)
+        print(f"R Lonely Drives: {lonely_drives}")
+        print(f"Amount Partitions: {drives_id}")
 
         return self.render(
             "netbox_storage/inc/template_drive_box.html",
             extra_context={
-                "lonely_drives": lonely_drive,
-                "linux_devices": linux_devices
+                "lonely_drives": lonely_drives,
+                "drives": drives_with_partition,
+                "partitions": partitions,
+                "amount_partitions": amount_partitions
             }
         )
 
@@ -79,19 +94,13 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         lonely_drive = []
         linux_devices = []
         for drive_id in drives:
-            print(drive_id['drive'])
             drives_id.append(drive_id['drive'])
             # if LinuxDevice.objects.filter(linux_device_drives=drive_id['drive']).count() == 0:
             drive = Drive.objects.get(pk=drive_id['drive'])
-            print(f"Lonely Drive: {drive}")
             lonely_drive.append(drive)
 #                print(LinuxDevice.objects.filter(linux_device_drives=drive_id['drive']))
 
         partitions = Partition.objects.filter(drive_id__in=drives_id)
-        print(f"Lonely Drives: {lonely_drive}")
-        print(f"Devices: {partitions}")
-        print(f"drives: {drives_id}")
-        print(linux_devices)
 
         return self.render(
             "netbox_storage/inc/template_box.html",
