@@ -45,7 +45,7 @@ from netbox_storage.views.linux_device import LinuxDeviceListView, LinuxDeviceEd
 from netbox_storage.views.logical_volume import LogicalVolumeDeleteView, LogicalVolumeEditView, LogicalVolumeView, \
     LogicalVolumeListView
 from netbox_storage.views.physical_volume import PhysicalVolumeDeleteView, PhysicalVolumeEditView, PhysicalVolumeView, \
-    PhysicalVolumeListView
+    PhysicalVolumeListView, PhysicalVolumeBulkImportView, PhysicalVolumeBulkEditView, PhysicalVolumeBulkDeleteView
 from netbox_storage.views.template import LVMAddTemplateView, AddTemplateDriveView, \
     AddTemplatePartitionView
 from netbox_storage.views.volume_group import VolumeGroupDeleteView, VolumeGroupEditView, VolumeGroupView, \
